@@ -106,13 +106,16 @@ static GtkTreeView *setup_make_view(PersonalMenuSetup *setup)
 		runInTerm="false";
 	    service=g_key_file_get_string(keyFile,entry,"service",NULL);
 
-	    icon_theme = gtk_icon_theme_get_default ();
-	    icon=gtk_icon_theme_load_icon(icon_theme,iconName,40,0,NULL);
-	    if (icon==NULL)
-	    {
-	      icon=gtk_icon_theme_load_icon(icon_theme,"qgn_list_gene_default_app",40,0,NULL);
-	    }
-	    icon=gdk_pixbuf_scale_simple(icon,40,40,GDK_INTERP_NEAREST);
+		if (executable!=NULL && g_strcasecmp(executable,"")!=0)
+		{
+			icon_theme = gtk_icon_theme_get_default ();
+			icon=gtk_icon_theme_load_icon(icon_theme,iconName,40,0,NULL);
+			if (icon==NULL)
+			{
+			  icon=gtk_icon_theme_load_icon(icon_theme,"qgn_list_gene_default_app",40,0,NULL);
+			}
+			icon=gdk_pixbuf_scale_simple(icon,40,40,GDK_INTERP_NEAREST);
+		}
 	    gtk_list_store_append(setup->entryList, &setup->entryIter);
 	    if (executable==NULL || g_strcasecmp(executable,"")==0)
 	    {
