@@ -325,13 +325,12 @@ static void menu_off(GtkMenu *menu, PersonalMenuNavigatorPlugin *plugin)
 }
 
 static void
-popup_menu(GtkWidget *button, GdkEventButton *event, PersonalMenuNavigatorPlugin *plugin)
+popup_menu(GtkToggleButton *button, PersonalMenuNavigatorPlugin *plugin)
 {
-	if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(plugin->button)))
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(plugin->button)))
 	{
 		gtk_menu_popup (GTK_MENU (plugin->menu),NULL,NULL,(GtkMenuPositionFunc)menu_position,plugin,0,gtk_get_current_event_time());
 		plugin->popped=TRUE;
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(plugin->button),TRUE);
 	}
 }
 
@@ -636,7 +635,7 @@ personal_menu_navigator_plugin_init (PersonalMenuNavigatorPlugin *navigator_plug
   button = personal_menu_button_new (10);
   navigator_plugin->button=button;
   
-  g_signal_connect(G_OBJECT(button),"button-release-event",G_CALLBACK(popup_menu),navigator_plugin);
+  g_signal_connect(G_OBJECT(button),"toggled",G_CALLBACK(popup_menu),navigator_plugin);
   
   gtk_widget_set_size_request (button, 80, 80);
   gtk_widget_set_name (button, "hildon-navigator-button-one");
